@@ -1,10 +1,17 @@
-library(modelsummary)
 penguins <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/palmerpenguins/penguins.csv")
 
+test_that("regression test: gt duplicate span labels", {
+    skip_if_not_installed("gt", minimum_version = "0.5.0")
+    expect_error(datasummary(All(mtcars) ~ Factor(vs) * (Factor(am) * (Mean + SD)),
+                             data = mtcars,
+                             output = "gt"),
+                NA)
+})
+
 
 test_that("tables::All() warning does not accept tibbles yet", {
   # https://github.com/vincentarelbundock/modelsummary/issues/395
-  skip_if_not_installed("tibble")
+  requiet("tibble")
   dat <- tibble::as_tibble(mtcars)
   expect_warning(datasummary(All(dat) ~ Mean + SD, data = dat), regexp = "does not accept tibbles")
   expect_warning(datasummary(All(mtcars) ~ Mean + SD, data = mtcars), NA)
@@ -75,12 +82,11 @@ test_that('numeric content of simple tables', {
 })
 
 test_that('Header carry-forward', {
-  coln <- c(" ", "4 mean", "4 sd", "6 mean", "6 sd", "8 mean", "8 sd",
-    "median")
+  coln <- c(" ", "4 / mean", "4 / sd", "6 / mean", "6 / sd", "8 / mean", "8 / sd", "median")
   tab <- datasummary(mpg + hp ~ Factor(cyl) * (mean + sd) + median,
     data = mtcars,
     output = 'dataframe')
-  expect_equal(coln, colnames(tab))
+  expect_equal(colnames(tab), coln)
 })
 
 test_that('Factor() is equivalent to assign', {
@@ -107,8 +113,8 @@ test_that('logical and characters converted to factors automatically', {
 })
 
 test_that('datasummary: output format do not produce errors', {
-  skip_if_not_installed("huxtable")
-  skip_if_not_installed("kableExtra")
+  requiet("huxtable")
+  requiet("kableExtra")
   # output formats do not produce errors
   expect_error(datasummary(All(mtcars) ~ Mean + SD, mtcars, output = 'huxtable'), NA)
   expect_error(datasummary(All(mtcars) ~ Mean + SD, mtcars, output = 'kableExtra'), NA)
@@ -120,7 +126,7 @@ test_that('datasummary: output format do not produce errors', {
 })
 
 test_that('datasummary: output format do not produce errors (flextable)', {
-  skip_if_not_installed("flextable")
+  requiet("flextable")
   expect_error(datasummary(All(mtcars) ~ Mean + SD, mtcars, output = 'flextable'), NA)
 })
 
@@ -146,3 +152,17 @@ test_that("labelled and All warning: Issue #433", {
     x <- structure(list(working_hours = structure(c( 28, 40, 11, NA, 40, 38, 10, 40, 43, 0), label = "Total hours normally worked per week in main job overtime included", format.stata = "%14.0g", labels = c( `Not applicable` = NA_real_, Refusal = NA_real_, `Don't know` = NA_real_, `No answer` = NA_real_), class = c("haven_labelled", "vctrs_vctr", "double")), age = structure(c( 53, 49, 16, 75, 41, 49, 64, 80, 62, 50), label = "Age of respondent, calculated", format.stata = "%13.0g", labels = c(`Not available` = NA_real_), class = c( "haven_labelled", "vctrs_vctr", "double")), group = structure(c( 1L, 2L, 1L, 2L, 2L, 1L, 1L, 2L, 2L, 2L), .Label = c("1", "2"), class = "factor")), class = "data.frame", row.names = c( NA, -10L))
     expect_warning(expect_error(datasummary_balance(~group, x)), regexp = "not safe")
 })
+
+
+test_that("regression test", {
+    url <- 'https://vincentarelbundock.github.io/Rdatasets/csv/palmerpenguins/penguins.csv'
+    penguins <- read.csv(url)
+    expect_error(datasummary(island * species * body_mass_g ~ sex * (Mean + SD),
+                             data = penguins),
+                 NA)
+    expect_error(datasummary(
+                     island * species * body_mass_g ~ sex * (Mean + SD) * DropEmpty(),
+                     data = penguins),
+                 NA)
+})
+
