@@ -8,7 +8,7 @@ test_that("options(modelsummary_get)", {
 
     options(modelsummary_get = "easystats")
     tab2 <- get_gof(mod)
-    expect_equal(ncol(tab2), 7)
+    expect_true(ncol(tab2) > 6)
     expect_true("rmse" %in% colnames(tab2))
 
     options(modelsummary_get = "all")
